#
# spec file for package img2pdf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           img2pdf
Version:        0.6.1
Release:        1.1
Summary:        Python module for converting images to PDF via direct JPEG inclusion
License:        LGPL-3.0-or-later
URL:            https://gitlab.mister-muffin.de/josch/img2pdf
Source:         https://files.pythonhosted.org/packages/source/i/img2pdf/img2pdf-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-pdfrw
Requires:       python-pikepdf
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if "%{python_flavor}" == "%{primary_python}"
Provides:       img2pdf
%endif
Suggests:       python-pdfrw
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pdfrw}
BuildRequires:  %{python_module pikepdf}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
This module losslessly converts raster images to PDF. The file size
will not unnecessarily increase. It can, for example, be used to
create a PDF document from a number of scans that are only available
in JPEG format. Existing solutions would either re-encode the input
JPEG files (leading to quality loss) or store them in the Deflate
format which results in the PDF becoming unnecessarily large in terms
of file size.

%prep
%setup -q -n img2pdf-%{version}
sed -i -e '/^#!\//, 1d' src/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/img2pdf-gui
%python_clone -a %{buildroot}%{_bindir}/img2pdf
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# other tests looks more like a integration tests, needs
# mupdf, imagemagick, pdftocairo, pdfimages, tiff-tools
%pytest -k '(test_general or test_layout) and not animation.gif'

%post
%python_install_alternative img2pdf-gui
%python_install_alternative img2pdf

%postun
%python_uninstall_alternative img2pdf-gui
%python_uninstall_alternative img2pdf

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.md
%python_alternative %{_bindir}/img2pdf
%python_alternative %{_bindir}/img2pdf-gui
%{python_sitelib}/*

%changelog
* Wed Apr 30 2025 ecsos <ecsos@opensuse.org>
- Update to 0.6.1
  - testsuite fixes
- Change from 0.6.0
  - Add support for JBIG2 (generic coding)
  - Add convert_to_docobject() broken out from convert()
  - Add pil_get_dpi() broken out from get_imgmetadata()
* Thu Jan  4 2024 ecsos <ecsos@opensuse.org>
- Update to 0.5.1
  * no default ICC profile location for PDF/A-1b on Windows
  * workaround for PNG input without dpi units but non-square dpi aspect ratio
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * support MIFF for 16 bit CMYK input
  * accept pathlib.Path objects as input
  * don't store RGB ICC profiles from bilevel or grayscale TIFF,
    PNG and JPEG
  * thumbnails are no longer included by default and --include-
    thumbnails has to be used if you want them
  * support for pikepdf (>= 6.2.0)
* Fri Aug 25 2023 Sebastian Wagner <sebix@sebix.at>
- Provide img2pdf for main flavor
* Fri Aug 25 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.4.4 (2022-04-07)
  - --viewer-page-layout support for twopageright and twopageleft
  - Add B and JB paper sizes
  - support for pikepdf (>= 5.0.0) and Pillow (>= 9.1.0)
* Mon Mar  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Skip two broken tests.
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.3:
  * fix --viewer-initial-page (broken in last release)
  * add --rotation
  * allow palette PNG images with ICC profile
  * sort globbing result on windows
  * convert 8-bit PNG alpha channels to /SMasks in PDF
  * remove pdfrw from tests
* Tue Oct 12 2021 pgajdos@suse.com
- version update to 0.4.1
  - support wildcards in paths on windows
  - support MPO images
  - fix page border computation
  - use "img2pdf" logger instead of "root" logger
  - add --from-file
- actually test the package, use at least part of the testsuite
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.0:
  - replace --without-pdfrw by --engine=internal or --engine=pdfrw
  - add pikepdf as additional rendering engine and add --engine=pikepdf
  - support for creating PDF/A-1b compliant PDF using the --pdfa option
    (this also requires the presence of an ICC profile somewhere on the system)
  - support for images with embedded ICC profile as input
  - rewrite tests
  * use pytest via tox
  * use pikepdf instead of pdfrw
  * use imagemagick json output instead of identify -verbose
  - format all code with black
  - fix tests for Fedora on arm64
  - remove all Python 2 support
  - disable pdfrw by default
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop py2 dep from py3 only package
* Thu Apr  9 2020 pgajdos@suse.com
- version update to 0.3.4
  - test.sh: replace imagemagick with custom python script to produce bit-by-bit
    identical results on all architectures
  - add --crop-border, --bleed-border, --trim-border and --art-border options
  - first draft of a rudimentary tkinter gui (run with --gui)
- python3 only per upstream declaration
- Drop patch python-img2pdf-test-python2.patch
* Wed Mar 27 2019 pgajdos@suse.com
- transformed sed to patch upon request
- added patches
  allow to run testsuite with python 2 (https://gitlab.mister-muffin.de/josch/img2pdf/issues/60)
  + python-img2pdf-test-python2.patch
* Wed Mar 27 2019 pgajdos@suse.com
- version update to 0.3.3
  * restore basic support for Python 2
  * also ship test.sh
  * add legal and tabloid paper formats
  * respect exif rotation tag
  * support big endian TIFF with lsb-to-msb FillOrder
  * support multipage CCITT Group 4 TIFF
  * also reject palette images with transparency
  * support PNG images with 1, 2, 4 or 16 bits per sample
  * support multipage TIFF with differently encoded images
  * support CCITT Group4 TIFF without rows-per-strip
  * add extensive test suite
  * Directly copy data from CCITT Group 4 encoded TIFF images into the PDF
    container without re-encoding
  * Store non-jpeg images using PNG compression
  * Support arbitrarily large pages via PDF /UserUnit field
  * Disallow input with alpha channel as it cannot be preserved
  * Add option --pillow-limit-break to support very large input
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase.
* Mon Jun  4 2018 toddrme2178@gmail.com
- spec file cleanups
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
